<?xml version="1.0" ?><!DOCTYPE TS><TS language="et" version="2.1">
<context>
    <name>ExpressionBar</name>
    <message>
        <source>Expression Error</source>
        <translation>Väljendi viga</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Dark theme</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Simple mode</source>
        <translation>Lihtne režiim</translation>
    </message>
    <message>
        <source>Scientific mode</source>
        <translation>Teaduslik</translation>
    </message>
    <message>
        <source>Deepin Calculator</source>
        <translation>Deepin kalkulaator</translation>
    </message>
    <message>
        <source>Deepin Calculator is a simple and easy to use desktop calculator. It supports addition, subtraction, multiplication and division.</source>
        <translation>Deepin kalkulaator on lihtne ja kergesti kasutatav töölaua kalkulaator. Se toetab liitmist, lahutamist, korrutamist ja jagamist.</translation>
    </message>
</context>
<context>
    <name>SimpleListDelegate</name>
    <message>
        <source>Expression Error</source>
        <translation>Väljendi viga</translation>
    </message>
</context>
</TS>